@@ -27,7 +27,7 @@ class RiteAidAPI:
         form = "refillPrescriptions={}&location={}&pickUpDate={}&pickUpTime={}&phone={}".format(
             quote(json.dumps(prescription_nums)).replace("%20", ""),
             quote(str(store_id)),
-            quote(date).replace("-", "%\2F"),
+            quote(date),
             quote(time).replace("%20", "+"),
             quote(phone),
         )
